@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,10 +36,11 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+
 from google.cloud.service_usage_v1.services.service_usage import pagers
-from google.cloud.service_usage_v1.types import resources
-from google.cloud.service_usage_v1.types import serviceusage
-from .transports.base import ServiceUsageTransport, DEFAULT_CLIENT_INFO
+from google.cloud.service_usage_v1.types import resources, serviceusage
+
+from .transports.base import DEFAULT_CLIENT_INFO, ServiceUsageTransport
 from .transports.grpc import ServiceUsageGrpcTransport
 from .transports.grpc_asyncio import ServiceUsageGrpcAsyncIOTransport
 
@@ -56,7 +57,10 @@ class ServiceUsageClientMeta(type):
     _transport_registry["grpc"] = ServiceUsageGrpcTransport
     _transport_registry["grpc_asyncio"] = ServiceUsageGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[ServiceUsageTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[ServiceUsageTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -167,7 +171,9 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -180,9 +186,13 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -191,9 +201,13 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -202,9 +216,13 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -213,10 +231,14 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -401,7 +423,6 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         r"""Enable a service so that it can be used with a
         project.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
@@ -463,7 +484,12 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -493,7 +519,6 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         ``FAILED_PRECONDITION`` status if the target service is not
         currently enabled.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
@@ -555,7 +580,12 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -579,7 +609,6 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         r"""Returns the service configuration and enabled state
         for a given service.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
@@ -633,7 +662,12 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -661,7 +695,6 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         which provides higher throughput and richer filtering
         capability.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
@@ -718,12 +751,20 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListServicesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -742,7 +783,6 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         no state changes occur. To enable a single service, use the
         ``EnableService`` method instead.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
@@ -804,7 +844,12 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -828,7 +873,6 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         r"""Returns the service configurations and enabled states
         for a given list of services.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
@@ -880,7 +924,12 @@ class ServiceUsageClient(metaclass=ServiceUsageClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
