@@ -13,22 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import operations_v1
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers, operations_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 import grpc  # type: ignore
 
-from google.cloud.service_usage_v1.types import resources
-from google.cloud.service_usage_v1.types import serviceusage
-from google.longrunning import operations_pb2  # type: ignore
-from .base import ServiceUsageTransport, DEFAULT_CLIENT_INFO
+from google.cloud.service_usage_v1.types import resources, serviceusage
+
+from .base import DEFAULT_CLIENT_INFO, ServiceUsageTransport
 
 
 class ServiceUsageGrpcTransport(ServiceUsageTransport):
@@ -233,8 +230,7 @@ class ServiceUsageGrpcTransport(ServiceUsageTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -440,5 +436,9 @@ class ServiceUsageGrpcTransport(ServiceUsageTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("ServiceUsageGrpcTransport",)
